==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ru/issues.php <==
<?php
regGS("Issue List", "Список выпусков");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Название<BR><SMALL>(щелкните для просмотра секций)</SMALL>");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Опубликовано<BR><SMALL>(гггг-мм-дд)</SMALL>");
regGS("Delete issue $1", "Удаление выпуска $1");
regGS("Publish articles", "Опубликовать статьи");
regGS("Change issue status", "Изменить статус выпуска");
regGS("You do not have the right to change issues.", "Вы не имеете права изменить выпуск.");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Вы уверены, что хотите поменять статус выпуска $1 с $2 на $3?");
regGS("Add new translation", "Добавить новый перевод");
regGS("You do not have the right to add issues.", "Вы не имеете права добавления выпуска.");
regGS("The issue $1 has been successfuly added.", "Выпуск $1 был успешно добавлен.");
regGS("The issue could not be added.", "Не удалось добавить выпуск.");
regGS("Please check if another issue with the same number/language does not already exist.", "Пожалуйста проверьте, что еще не существует другого выпуска с таким же номером/языком.");
regGS("Change issue details", "Сменить параметры выпуска");
regGS("You do not have the right to change issue details.", "Вы не имеете права изменить параметры выпуска.");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Дата публикации<BR><SMALL>(гггг-мм-дд)</SMALL>");
regGS("Front Page Template", "Шаблон титульной страницы");
regGS("Issue $1 updated in publication $2", "Выпуск $1 обновлен в публикации $2");
regGS("You do not have the right to delete issues.", "Вы не имеете права удаления выпусков.");
regGS("Are you sure you want to delete the issue $1?", "Вы уверены, что хотите удалить выпуск $1?");
regGS("Deleting issue", "Удаление выпуска");
regGS("Use the structure of the previous issue", "Использовать структуру предыдущего выпуска");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Скопировать всю структуру записи во все языки из предыдущего выпуска за исключением информационого наполнения.");
regGS("You may modify it later if you wish.", "Вы можете модифицировать это позже, если пожелаете.");
regGS("Create a new structure", "Создать новую структуру");
regGS("Create a complete new structure.", "Создать полностью новую структуру.");
regGS("You must define an issue type for each language and then sections for them.", "Вы должны определить тип выпуска для каждого языка и, затем, секции для них.");
regGS("Copy previous issue", "Скопировать предыдущий выпуск");
regGS("No previous issue.", "Нет предыдущего выпуска.");
regGS("Copy structure from issue nr $1", "Скопировать структуру из выпуска №$1");
regGS("Copying previous issue", "Копирование предыдущего выпуска:");
regGS("Select the issue", "Выберите выпуск");
regGS("New issue $1 from $2 in publication $3", "Новый выпуск $1 из $2 в публикации $3");
regGS("Adding new issue", "Добавление нового выпуска");
regGS("Delete entry", "Удалить запись");
regGS("Issue Publishing Schedule", "Публикация выпуска запланирована");
regGS("Invalid Input: $1", "Неправильный ввод: $1");
regGS("Issue Number", "Номер выпуска");
regGS("Go To Sections", "Перейти к секциям");
regGS("No such issue.", "Нет такого выпуска.");
regGS("Change Issue Status", "Изменить состояние выпуска");
regGS("Are you sure you want to delete this event?", "Вы уверены, что хотите удалить это событие");
regGS("Changing issue status", "Изменение статуса выпуска");
regGS("Status of the issue $1 has been changed from $2 to $3", "Статус выпуска $1 был изменен с $2 на $3");
regGS("Updating issue", "Обновление выпуска");
regGS("Changing issue's details", "Изменение параметров выпуска");
regGS("The issue $1 has been successfuly changed.", "Выпуск $1 был успешно изменен.");
regGS("The issue could not be changed.", "Не удалось изменить выпуск.");
regGS("Changing issue template", "Изменение шаблона выпуска");
regGS("You do not have the right to change issue templates.", "Вы не имеете права смены шаблона выпуска.");
regGS("Changing issue template for front page", "Изменение шаблона выпуска для титульной страницы");
regGS("Changing issue template for single article", "Изменение шаблона выпуска для отдельной страницы");
regGS("The template has been successfully changed.", "Шаблон был успешно изменен.");
regGS("Issue template for publication $1 changed to $2", "Шаблон выпуска для публикации $1 изменен на $2");
regGS("Issue template for single articles from $1 changed to $2", "Шаблон выпуска для отдельной статьи изменен с $1 на $2");
regGS("The template could not be changed.", "Не удалось изменить шаблон.");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Шаблон титульной страницы<BR><SMALL>(щелкните для изменения)</SMALL>:ru");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Шаблон отдельной статьи<BR><SMALL>(щелкните для изменения)</SMALL>:ru");
regGS("Preview issue", "Предварительный просмотр выпуска:ru");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Невозможно просмотреть этот выпуск. Пожалуйста убедитесь, что у него выбран шаблон $1.:ru");
regGS("front page", "титульная страница:ru");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/ru/issues.php <==
<?php 
regGS("Change issue status", "Изменить статус выпуска");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "Величины, которые вы пытаетесь установить, конфликтуют с выпуском \"$1$2. $3 ($4)$5\".");
regGS("The number must be unique for each issue in this publication of the same language.", "Номер должен быть уникальным для каждого выпуска в этой публикации того же языка.");
regGS("The language and URL name must be unique for each issue in this publication.", "Язык и URL доолжен быть уникальным для каждого выпуска в этой публикации.");
regGS("Issue created.", "Выпуск создан.");
regGS("Issue updated", "Выпуск обновлен.");
regGS("Could not save the changes to the issue.", "Не удалось сохранить изменения в выпуске.");
regGS("Unpublish on: $1", "Отменить публикацию на: $1");
regGS("There are $1 articles in this issue.", "Статей в выпуске: $1.");
regGS("The issue $1 has been deleted.", "Выпуск $1 был удален.");
regGS("Schedule", "Расписание");
regGS("Publish on: $1", "Публиковать: $1");
regGS("Publish Date $1", "Дата публикации $1");
regGS("Deleted issue", "Удаленный выпуск");
regGS("Delete issue", "Удалить выпуск");
regGS("Click here to publish this issue", "Щелкните здесь для публикации выпуска");
regGS("A total of $1 articles were deleted.", "Всего статей было удалено: $1");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Название<BR><SMALL>(щелкните для просмотра секций)</SMALL>");
regGS("Delete issue $1", "Удаление выпуска $1");
regGS("Publish articles", "Опубликовать статьи");
regGS("You do not have the right to change issues.", "Вы не имеете права изменить выпуск.");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Вы уверены, что хотите поменять статус выпуска $1 с $2 на $3?");
regGS("Add new translation", "Добавить новый перевод");
regGS("You do not have the right to add issues.", "Вы не имеете права добавления выпуска.");
regGS("The issue $1 has been successfuly added.", "Выпуск $1 был успешно добавлен.");
regGS("The issue could not be added.", "Не удалось добавить выпуск.");
regGS("Change issue details", "Сменить параметры выпуска");
regGS("You do not have the right to change issue details.", "Вы не имеете права изменить параметры выпуска.");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Дата публикации<BR><SMALL>(гггг-мм-дд)</SMALL>");
regGS("Front Page Template", "Шаблон титульной страницы");
regGS("Issue $1 updated in publication $2", "Выпуск $1 обновлен в публикации $2");
regGS("You do not have the right to delete issues.", "Вы не имеете права удаления выпусков.");
regGS("Are you sure you want to delete the issue $1?", "Вы уверены, что хотите удалить выпуск $1?");
regGS("Use the structure of the previous issue", "Использовать структуру предыдущего выпуска");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Скопировать всю структуру записи во все языки из предыдущего выпуска за исключением информационого наполнения.");
regGS("You may modify it later if you wish.", "Вы можете модифицировать это позже, если пожелаете.");
regGS("Create a new structure", "Создать новую структуру");
regGS("Create a complete new structure.", "Создать полностью новую структуру.");
regGS("You must define an issue type for each language and then sections for them.", "Вы должны определить тип выпуска для каждого языка и, затем, секции для них.");
regGS("Copy previous issue", "Скопировать предыдущий выпуск");
regGS("No previous issue.", "Нет предыдущего выпуска.");
regGS("Copy structure from issue number $1", "Скопировать структуру из выпуска №$1");
regGS("New issue $1 from $2 in publication $3", "Новый выпуск $1 из $2 в публикации $3");
regGS("Delete entry", "Удалить запись");
regGS("Issue Publishing Schedule", "Публикация выпуска запланирована");
regGS("Invalid Input: $1", "Неправильный ввод: $1");
regGS("Issue Number", "Номер выпуска");
regGS("Go To Sections", "Перейти к секциям");
regGS("There was an error reading the language parameter.", "Ошибка чтения параметров языка");
regGS("There was an error reading the publication parameter.", "Ошибка чтения параметров публикации");
regGS("There was an error reading the issue parameter.", "Ошибка чтения параметров выпуска");
regGS("There was an error scheduling the $1 action on $2", "Ошибка планирования операции $1 на $2");
regGS("The action scheduled on $1 could not be deleted.", "Назначенная на $1 операция не может быть отменена");
regGS("No such issue.", "Нет такого выпуска.");
regGS("Change Issue Status", "Изменить состояние выпуска");
regGS("Are you sure you want to delete this event?", "Вы уверены, что хотите удалить это событие");
regGS("Changing issue status", "Изменение статуса выпуска");
regGS("Status of the issue $1 has been changed from $2 to $3", "Статус выпуска $1 был изменен с $2 на $3");
regGS("Updating issue", "Обновление выпуска");
regGS("Changing issue's details", "Изменение параметров выпуска");
regGS("The issue $1 has been successfuly changed.", "Выпуск $1 был успешно изменен.");
regGS("The issue could not be changed.", "Не удалось изменить выпуск.");
regGS("Changing issue template", "Изменение шаблона выпуска");
regGS("You do not have the right to change issue templates.", "Вы не имеете права смены шаблона выпуска.");
regGS("Changing issue template for front page", "Изменение шаблона выпуска для титульной страницы");
regGS("Changing issue template for single article", "Изменение шаблона выпуска для отдельной страницы");
regGS("The template has been successfully changed.", "Шаблон был успешно изменен.");
regGS("Issue template for publication $1 changed to $2", "Шаблон выпуска для публикации $1 изменен на $2");
regGS("Issue template for single articles from $1 changed to $2", "Шаблон выпуска для отдельной статьи изменен с $1 на $2");
regGS("The template could not be changed.", "Не удалось изменить шаблон.");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Шаблон титульной страницы<BR><SMALL>(щелкните для изменения)</SMALL>:ru");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Шаблон отдельной статьи<BR><SMALL>(щелкните для изменения)</SMALL>:ru");
regGS("Preview issue", "Предварительный просмотр выпуска:ru");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Невозможно просмотреть этот выпуск. Пожалуйста убедитесь, что у него выбран шаблон $1.:ru");
regGS("front page", "титульная страница:ru");
?>
